@@ -89,7 +89,7 @@ SIGN_PERSONAL_SEAL - 个人签署印章控件；
 
 表单域的控件不能作为印章和签名控件
         :type ComponentType: str
-        :param ComponentName: 控件名称
+        :param ComponentName: 控件简称
         :type ComponentName: str
         :param ComponentRequired: 定义控件是否为必填项，默认为false
         :type ComponentRequired: bool
@@ -376,10 +376,13 @@ class CreateSignUrlsResponse(AbstractModel):
         r"""
         :param SignUrlInfos: 签署参与者签署H5链接信息数组
         :type SignUrlInfos: list of SignUrlInfo
+        :param ErrorMessages: 生成失败时的错误信息，成功返回”“，顺序和出参SignUrlInfos保持一致
+        :type ErrorMessages: list of str
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
         self.SignUrlInfos = None
+        self.ErrorMessages = None
         self.RequestId = None
 
 
@@ -390,6 +393,74 @@ class CreateSignUrlsResponse(AbstractModel):
                 obj = SignUrlInfo()
                 obj._deserialize(item)
                 self.SignUrlInfos.append(obj)
+        self.ErrorMessages = params.get("ErrorMessages")
+        self.RequestId = params.get("RequestId")
+
+
+class DescribeResourceUrlsByFlowsRequest(AbstractModel):
+    """DescribeResourceUrlsByFlows请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param Agent: 渠道应用相关信息
+        :type Agent: :class:`tencentcloud.essbasic.v20210526.models.Agent`
+        :param Operator: 操作者的信息
+        :type Operator: :class:`tencentcloud.essbasic.v20210526.models.UserInfo`
+        :param FlowIds: 查询资源所对应的流程Id
+        :type FlowIds: list of str
+        """
+        self.Agent = None
+        self.Operator = None
+        self.FlowIds = None
+
+
+    def _deserialize(self, params):
+        if params.get("Agent") is not None:
+            self.Agent = Agent()
+            self.Agent._deserialize(params.get("Agent"))
+        if params.get("Operator") is not None:
+            self.Operator = UserInfo()
+            self.Operator._deserialize(params.get("Operator"))
+        self.FlowIds = params.get("FlowIds")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class DescribeResourceUrlsByFlowsResponse(AbstractModel):
+    """DescribeResourceUrlsByFlows返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param FlowResourceUrlInfos: 流程资源对应链接信息
+        :type FlowResourceUrlInfos: list of FlowResourceUrlInfo
+        :param ErrorMessages: 创建消息，对应多个合同ID，
+成功为“”,创建失败则对应失败消息
+        :type ErrorMessages: list of str
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.FlowResourceUrlInfos = None
+        self.ErrorMessages = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        if params.get("FlowResourceUrlInfos") is not None:
+            self.FlowResourceUrlInfos = []
+            for item in params.get("FlowResourceUrlInfos"):
+                obj = FlowResourceUrlInfo()
+                obj._deserialize(item)
+                self.FlowResourceUrlInfos.append(obj)
+        self.ErrorMessages = params.get("ErrorMessages")
         self.RequestId = params.get("RequestId")
 
 
@@ -663,6 +734,41 @@ class FlowInfo(AbstractModel):
         
 
 
+class FlowResourceUrlInfo(AbstractModel):
+    """流程对应资源链接信息
+
+    """
+
+    def __init__(self):
+        r"""
+        :param FlowId: 流程对应Id
+注意：此字段可能返回 null，表示取不到有效值。
+        :type FlowId: str
+        :param ResourceUrlInfos: 流程对应资源链接信息数组
+注意：此字段可能返回 null，表示取不到有效值。
+        :type ResourceUrlInfos: list of ResourceUrlInfo
+        """
+        self.FlowId = None
+        self.ResourceUrlInfos = None
+
+
+    def _deserialize(self, params):
+        self.FlowId = params.get("FlowId")
+        if params.get("ResourceUrlInfos") is not None:
+            self.ResourceUrlInfos = []
+            for item in params.get("ResourceUrlInfos"):
+                obj = ResourceUrlInfo()
+                obj._deserialize(item)
+                self.ResourceUrlInfos.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
 class FormField(AbstractModel):
     """此结构 (FormField) 用于描述内容控件填充结构。
 
@@ -859,6 +965,41 @@ class Recipient(AbstractModel):
         
 
 
+class ResourceUrlInfo(AbstractModel):
+    """资源链接信息
+
+    """
+
+    def __init__(self):
+        r"""
+        :param Url: 资源链接地址，过期时间5分钟
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Url: str
+        :param Name: 资源名称
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Name: str
+        :param Type: 资源类型
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Type: str
+        """
+        self.Url = None
+        self.Name = None
+        self.Type = None
+
+
+    def _deserialize(self, params):
+        self.Url = params.get("Url")
+        self.Name = params.get("Name")
+        self.Type = params.get("Type")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
 class SignUrlInfo(AbstractModel):
     """签署链接内容
 
@@ -901,6 +1042,9 @@ PERSON 自然人
         :param FlowId: 签署链接对应流程Id
 注意：此字段可能返回 null，表示取不到有效值。
         :type FlowId: str
+        :param OpenId: 企业经办人 用户在渠道的编号
+注意：此字段可能返回 null，表示取不到有效值。
+        :type OpenId: str
         """
         self.SignUrl = None
         self.Deadline = None
@@ -913,6 +1057,7 @@ PERSON 自然人
         self.ApproverType = None
         self.IdCardNumber = None
         self.FlowId = None
+        self.OpenId = None
 
 
     def _deserialize(self, params):
@@ -927,6 +1072,7 @@ PERSON 自然人
         self.ApproverType = params.get("ApproverType")
         self.IdCardNumber = params.get("IdCardNumber")
         self.FlowId = params.get("FlowId")
+        self.OpenId = params.get("OpenId")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -1192,16 +1338,21 @@ class UsageDetail(AbstractModel):
         :param Date: 日期，当需要汇总数据时日期为空
 注意：此字段可能返回 null，表示取不到有效值。
         :type Date: str
+        :param ProxyOrganizationName: 渠道侧合作企业名
+注意：此字段可能返回 null，表示取不到有效值。
+        :type ProxyOrganizationName: str
         """
         self.ProxyOrganizationOpenId = None
         self.Usage = None
         self.Date = None
+        self.ProxyOrganizationName = None
 
 
     def _deserialize(self, params):
         self.ProxyOrganizationOpenId = params.get("ProxyOrganizationOpenId")
         self.Usage = params.get("Usage")
         self.Date = params.get("Date")
+        self.ProxyOrganizationName = params.get("ProxyOrganizationName")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
